@@ -11,7 +11,7 @@ use serde::Serialize;
 use std::path::PathBuf;
 use structopt::clap::AppSettings::{
     self, AllArgsOverrideSelf, AllowExternalSubcommands, AllowLeadingHyphen, DisableHelpFlags,
-    DisableHelpSubcommand, DisableVersion, TrailingVarArg,
+    DisableHelpSubcommand, DisableVersion, Hidden, TrailingVarArg,
 };
 use structopt::StructOpt;
 
@@ -19,6 +19,8 @@ mod completion;
 pub use completion::*;
 mod tags;
 pub use tags::*;
+mod types;
+pub use types::*;
 
 const NO_FLAG_SETTINGS: &[AppSettings] = &[
     AllowLeadingHyphen,
@@ -158,12 +160,12 @@ pub enum Subs {
         setting = AllowLeadingHyphen
     )]
     Help { args: Vec<String> },
-    #[structopt(about = "Print the help message of env variables")]
+    #[structopt(setting = Hidden, about = "Print the help message of env variables")]
     EnvHelp {
         #[structopt(default_value = "-", parse(try_from_str))]
         script_query: ScriptQuery,
     },
-    #[structopt(setting = AppSettings::Hidden)]
+    #[structopt(setting = Hidden)]
     LoadUtils,
     #[structopt(about = "Migrate the database")]
     Migrate,
@@ -206,8 +208,8 @@ pub enum Subs {
     Run {
         #[structopt(long, help = "Add a dummy run history instead of actually running it")]
         dummy: bool,
-        #[structopt(long, short, default_value = "1")]
-        repeat: u64,
+        #[structopt(long, short)]
+        repeat: Option<u64>,
         #[structopt(long, short, help = "Use arguments from last run")]
         previous_args: bool,
         #[structopt(long, short, requires = "previous-args")]
@@ -239,8 +241,8 @@ pub enum Subs {
     },
     #[structopt(about = "List hyper scripts")]
     LS(List),
-    #[structopt(about = "List all existing types")]
-    Types,
+    #[structopt(about = "Manage script types")]
+    Types(Types),
     #[structopt(about = "Copy the script to another one")]
     CP {
         #[structopt(long, short)]
@@ -413,6 +415,9 @@ impl Root {
             Some(Subs::Tags(tags)) => {
                 tags.sanitize();
             }
+            Some(Subs::Types(types)) => {
+                types.sanitize();
+            }
             None => {
                 log::info!("無參數模式");
                 self.subcmd = Some(Subs::Edit {
@@ -522,7 +527,7 @@ mod test {
             Some(Subs::Run {
                 dummy: true,
                 previous_args: false,
-                repeat: 42,
+                repeat: Some(42),
                 dir: None,
                 script_query,
                 args,
