@@ -1,5 +1,7 @@
 use fxhash::FxHashMap as HashMap;
-use hyper_scripter::args::{self, History, List, Root, Subs, Tags, TagsSubs};
+use hyper_scripter::args::{
+    self, History, List, Root, RootArgs, Subs, Tags, TagsSubs, Types, TypesSubs,
+};
 use hyper_scripter::config::{Config, NamedTagFilter};
 use hyper_scripter::error::{Error, RedundantOpt, Result};
 use hyper_scripter::extract_msg::{extract_env_from_content, extract_help_from_content};
@@ -80,6 +82,19 @@ struct MainReturn {
     /// 用來裝那種不會馬上造成中止的錯誤，例如 ScriptError
     errs: Vec<Error>,
 }
+struct RepoHolder {
+    root_args: RootArgs,
+    need_journal: bool,
+}
+impl RepoHolder {
+    async fn init(self) -> Result<ScriptRepo> {
+        util::init_repo(self.root_args, self.need_journal).await
+    }
+    async fn historian(self) -> Result<Historian> {
+        let historian = Historian::new(path::get_home().to_owned()).await?;
+        Ok(historian)
+    }
+}
 
 async fn main_inner(root: Root) -> Result<MainReturn> {
     Config::set_prompt_level(root.root_args.prompt_level);
@@ -87,8 +102,10 @@ async fn main_inner(root: Root) -> Result<MainReturn> {
 
     let conf = Config::get();
     let need_journal = main_util::need_write(root.subcmd.as_ref().unwrap());
-    let mut repo = util::init_repo(root.root_args, need_journal).await?;
-    let historian = repo.historian().clone();
+    let repo = RepoHolder {
+        root_args: root.root_args,
+        need_journal,
+    };
 
     let mut ret = MainReturn {
         conf: None,
@@ -103,7 +120,7 @@ async fn main_inner(root: Root) -> Result<MainReturn> {
     }
 
     match root.subcmd.unwrap() {
-        Subs::LoadUtils => main_util::load_utils(&mut repo).await?,
+        Subs::LoadUtils => main_util::load_utils(&mut repo.init().await?).await?,
         Subs::Alias {
             unset: false,
             before: Some(before),
@@ -162,6 +179,7 @@ async fn main_inner(root: Root) -> Result<MainReturn> {
             no_template,
         } => {
             // TODO: 這裡邏輯太複雜了，抽出來測試吧
+            let mut repo = repo.init().await?;
             let edit_tags = {
                 // TODO: 不要這麼愛 clone
                 let mut innate_tags = conf.main_tag_filter.clone();
@@ -187,11 +205,9 @@ async fn main_inner(root: Root) -> Result<MainReturn> {
                 main_util::edit_or_create(edit_query, &mut repo, ty, edit_tags).await?;
             let prepare_resp = util::prepare_script(&path, &*entry, no_template, &content)?;
             if !fast {
-                let cmd = util::create_concat_cmd(&conf.editor, &[&path]);
-                let stat = util::run_cmd(cmd)?;
-                if !stat.success() {
-                    let code = stat.code().unwrap_or_default();
-                    ret.errs.push(Error::EditorError(code, conf.editor.clone()));
+                let res = util::open_editor(&path);
+                if let Err(err) = res {
+                    ret.errs.push(err);
                 }
             }
             let should_keep = main_util::after_script(&mut entry, &path, &prepare_resp).await?;
@@ -201,6 +217,7 @@ async fn main_inner(root: Root) -> Result<MainReturn> {
             }
         }
         Subs::Help { args } => {
+            let mut repo = repo.init().await?;
             let script_query: ScriptQuery = args[0].parse()?;
             let mut entry = query::do_script_query_strict(&script_query, &mut repo).await?;
             log::info!("檢視用法： {:?}", entry.name);
@@ -223,13 +240,13 @@ async fn main_inner(root: Root) -> Result<MainReturn> {
             repeat,
             dir,
         } => {
+            let mut repo = repo.init().await?;
             let mut entry = query::do_script_query_strict(&script_query, &mut repo).await?;
             main_util::run_n_times(
-                repeat,
+                repeat.unwrap_or(1),
                 dummy,
                 &mut entry,
                 args,
-                historian,
                 &mut ret.errs,
                 previous_args,
                 dir,
@@ -237,6 +254,7 @@ async fn main_inner(root: Root) -> Result<MainReturn> {
             .await?;
         }
         Subs::Which { script_query } => {
+            let mut repo = repo.init().await?;
             let entry = query::do_script_query_strict(&script_query, &mut repo).await?;
             log::info!("定位 {:?}", entry.name);
             // NOTE: 不檢查存在與否
@@ -244,6 +262,7 @@ async fn main_inner(root: Root) -> Result<MainReturn> {
             println!("{}", p.to_string_lossy());
         }
         Subs::Cat { script_query } => {
+            let mut repo = repo.init().await?;
             let mut entry = query::do_script_query_strict(&script_query, &mut repo).await?;
             log::info!("打印 {:?}", entry.name);
             let script_path = path::open_script(&entry.name, &entry.ty, Some(true))?;
@@ -252,6 +271,7 @@ async fn main_inner(root: Root) -> Result<MainReturn> {
             create_read_event(&mut entry).await?;
         }
         Subs::EnvHelp { script_query } => {
+            let mut repo = repo.init().await?;
             let mut entry = query::do_script_query_strict(&script_query, &mut repo).await?;
             log::info!("打印 {:?} 的環境變數", entry.name);
             create_read_event(&mut entry).await?;
@@ -262,9 +282,22 @@ async fn main_inner(root: Root) -> Result<MainReturn> {
                 println!("{}", msg);
             }
         }
-        Subs::Types => {
+        Subs::Types(Types {
+            subcmd: Some(TypesSubs::LS),
+        }) => {
             print_iter(conf.types.keys(), " ");
         }
+        Subs::Types(Types {
+            subcmd: Some(TypesSubs::Template { ty, edit }),
+        }) => {
+            if edit {
+                let tmpl_path = util::get_template_path(&ty, false)?;
+                util::open_editor(&tmpl_path)?;
+            } else {
+                let template = util::get_or_create_tamplate(&ty, false)?;
+                println!("{}", template);
+            }
+        }
         Subs::LS(List {
             long,
             grouping,
@@ -288,9 +321,10 @@ async fn main_inner(root: Root) -> Result<MainReturn> {
                 display_style,
             };
             let stdout = std::io::stdout();
-            fmt_list(&mut stdout.lock(), &mut repo, &opt).await?;
+            fmt_list(&mut stdout.lock(), &mut repo.init().await?, &opt).await?;
         }
         Subs::RM { queries, purge } => {
+            let mut repo = repo.init().await?;
             let delete_tag: Option<TagFilter> = Some("+removed".parse().unwrap());
             let mut to_purge = vec![]; // (name, ty, id)
             for mut entry in query::do_list_query(&mut repo, &queries).await?.into_iter() {
@@ -320,6 +354,7 @@ async fn main_inner(root: Root) -> Result<MainReturn> {
             }
         }
         Subs::CP { origin, new, tags } => {
+            let mut repo = repo.init().await?;
             if repo.get_mut(&new, true).is_some() {
                 return Err(Error::ScriptExist(new.to_string()));
             }
@@ -348,6 +383,7 @@ async fn main_inner(root: Root) -> Result<MainReturn> {
             tags,
             ty,
         } => {
+            let mut repo = repo.init().await?;
             let new_name = match new {
                 Some(name) => {
                     if repo.get_mut(&name, true).is_some() {
@@ -403,11 +439,23 @@ async fn main_inner(root: Root) -> Result<MainReturn> {
             filter.inactivated = !filter.inactivated;
         }
         Subs::Tags(Tags {
-            subcmd: Some(TagsSubs::LS { named, known }),
+            subcmd:
+                Some(TagsSubs::LS {
+                    named: true,
+                    known: false,
+                }),
         }) => {
-            if named {
-                print_iter(conf.tag_filters.iter().map(|f| &f.name), " ");
-            } else if known {
+            print_iter(conf.tag_filters.iter().map(|f| &f.name), " ");
+        }
+        Subs::Tags(Tags {
+            subcmd:
+                Some(TagsSubs::LS {
+                    named: false,
+                    known,
+                }),
+        }) => {
+            let mut repo = repo.init().await?;
+            if known {
                 print_iter(known_tags_iter(&mut repo), " ");
             } else {
                 print!("known tags:\n  ");
@@ -459,6 +507,8 @@ async fn main_inner(root: Root) -> Result<MainReturn> {
         Subs::History {
             subcmd: History::RM { script, range },
         } => {
+            let mut repo = repo.init().await?;
+            let historian = repo.historian().clone();
             let mut entry = query::do_script_query_strict(&script, &mut repo).await?;
             let res = match range {
                 RangeQuery::Single(n) => historian.ignore_args(entry.id, n).await?,
@@ -478,22 +528,25 @@ async fn main_inner(root: Root) -> Result<MainReturn> {
         Subs::History {
             subcmd: History::RMID { event_id },
         } => {
-            process_event_by_id(false, &mut repo, &historian, event_id).await?;
+            process_event_by_id(false, repo, event_id).await?;
         }
         Subs::History {
             subcmd: History::Humble { event_id },
         } => {
-            process_event_by_id(true, &mut repo, &historian, event_id).await?;
+            process_event_by_id(true, repo, event_id).await?;
         }
         Subs::History {
             subcmd: History::Amend { event_id, args },
         } => {
+            let historian = repo.historian().await?;
             let args = serde_json::to_string(&args)?;
             historian.amend_args_by_id(event_id as i64, &args).await?
         }
         Subs::History {
             subcmd: History::Tidy { queries },
         } => {
+            let mut repo = repo.init().await?;
+            let historian = repo.historian().clone();
             for entry in query::do_list_query(&mut repo, &queries).await?.into_iter() {
                 historian.tidy(entry.id).await?;
             }
@@ -501,6 +554,7 @@ async fn main_inner(root: Root) -> Result<MainReturn> {
         Subs::History {
             subcmd: History::Neglect { queries },
         } => {
+            let mut repo = repo.init().await?;
             for entry in query::do_list_query(&mut repo, &queries).await?.into_iter() {
                 let id = entry.id;
                 entry.get_env().handle_neglect(id).await?;
@@ -516,6 +570,8 @@ async fn main_inner(root: Root) -> Result<MainReturn> {
                     dir,
                 },
         } => {
+            let mut repo = repo.init().await?;
+            let historian = repo.historian().clone();
             let dir = util::option_map_res(dir, |d| path::normalize_path(d))?;
             let entry = query::do_script_query_strict(&script, &mut repo).await?;
             let args_list = historian
@@ -567,12 +623,9 @@ fn known_tags_iter<'a>(repo: &'a mut ScriptRepo) -> impl Iterator<Item = &'a Tag
     v.into_iter().map(|(k, _)| k)
 }
 
-async fn process_event_by_id(
-    is_humble: bool,
-    repo: &mut ScriptRepo,
-    historian: &Historian,
-    event_id: u64,
-) -> Result {
+async fn process_event_by_id(is_humble: bool, repo: RepoHolder, event_id: u64) -> Result {
+    let mut repo = repo.init().await?;
+    let historian = repo.historian();
     let event_id = event_id as i64;
     let res = if is_humble {
         historian.humble_args_by_id(event_id).await?
