@@ -1,7 +1,10 @@
 use crate::error::Result;
 use crate::state::State;
 use futures::future::join_all;
-use fuzzy_matcher::{skim::SkimMatcherV2, FuzzyMatcher};
+use fuzzy_matcher::{
+    skim::{SkimMatcherV2, SkimScoreConfig},
+    FuzzyMatcher,
+};
 use std::borrow::Cow;
 use std::cmp::{Ordering, PartialOrd};
 use tokio::task::spawn_blocking;
@@ -130,7 +133,11 @@ pub async fn fuzz_with_multifuzz_ratio<'a, T: FuzzKey + Send + 'a>(
     let mut data_vec: Vec<_> = iter.map(|t| (FuzzScore::default(), t)).collect();
     let sep = MyRaw::new(sep);
 
-    crate::set_once!(MATCHER, SkimMatcherV2::default);
+    crate::set_once!(MATCHER, || {
+        let mut conf = SkimScoreConfig::default();
+        conf.bonus_consecutive *= 4;
+        SkimMatcherV2::default().score_config(conf)
+    });
 
     let score_fut = data_vec.iter_mut().map(|(score, data)| {
         let key = MyCow::new(data.fuzz_key());
