@@ -1,7 +1,6 @@
 use crate::config::Config;
 use crate::error::{Contextable, Error, Result};
-use crate::extract_msg::extract_env_from_content;
-use crate::path::{get_home, get_template_path, normalize_path};
+use crate::path;
 use crate::script::ScriptInfo;
 use crate::script_type::{get_default_template, ScriptType};
 use chrono::{DateTime, Utc};
@@ -30,90 +29,6 @@ pub fn illegal_name(s: &str) -> bool {
         || s.is_empty()
 }
 
-// XXX: main util?
-pub fn run(
-    script_path: &Path,
-    info: &ScriptInfo,
-    remaining: &[String],
-    content: &str,
-    run_id: i64,
-) -> Result<()> {
-    let conf = Config::get();
-    let ty = &info.ty;
-    let name = &info.name.key();
-    let hs_home = get_home();
-    let hs_tags: Vec<_> = info.tags.iter().map(|t| t.as_ref()).collect();
-
-    let hs_exe = std::env::current_exe()?;
-    let hs_exe = hs_exe.to_string_lossy();
-
-    let hs_cmd = std::env::args().next().unwrap_or_default();
-
-    let hs_env_help: Vec<_> = extract_env_from_content(content).collect();
-
-    let script_conf = conf.get_script_conf(ty)?;
-    let cmd_str = if let Some(cmd) = &script_conf.cmd {
-        cmd
-    } else {
-        return Err(Error::PermissionDenied(vec![script_path.to_path_buf()]));
-    };
-
-    macro_rules! remaining_iter {
-        () => {
-            remaining.iter().map(|s| AsRef::<OsStr>::as_ref(s))
-        };
-    }
-
-    let info: serde_json::Value;
-    info = json!({
-        "path": script_path,
-        "hs_home": hs_home,
-        "hs_run_id": run_id,
-        "hs_tags": hs_tags,
-        "hs_cmd": hs_cmd,
-        "hs_exe": hs_exe,
-        "hs_env_help": hs_env_help,
-        "name": name,
-        "content": content,
-    });
-    let env = conf.gen_env(&info)?;
-    let ty_env = script_conf.gen_env(&info)?;
-
-    if let Some(pre_run_script) = find_pre_run() {
-        let args = std::iter::once(pre_run_script.as_ref()).chain(remaining_iter!());
-        let mut cmd = create_cmd("sh", args);
-        cmd.envs(ty_env.iter().map(|(a, b)| (a, b)));
-        cmd.envs(env.iter().map(|(a, b)| (a, b)));
-
-        let stat = run_cmd(cmd)?;
-        log::info!("預腳本執行結果：{:?}", stat);
-        if !stat.success() {
-            // TODO: 根據返回值做不同表現
-            let code = stat.code().unwrap_or_default();
-            return Err(Error::PreRunError(code));
-        }
-    }
-
-    let args = script_conf.args(&info)?;
-    let full_args: Vec<&OsStr> = args
-        .iter()
-        .map(|s| s.as_ref())
-        .chain(remaining_iter!())
-        .collect();
-
-    let mut cmd = create_cmd(&cmd_str, &full_args);
-    cmd.envs(ty_env);
-    cmd.envs(env);
-
-    let stat = run_cmd(cmd)?;
-    log::info!("程式執行結果：{:?}", stat);
-    if !stat.success() {
-        let code = stat.code().unwrap_or_default();
-        Err(Error::ScriptError(code))
-    } else {
-        Ok(())
-    }
-}
 pub fn run_cmd(mut cmd: Command) -> Result<ExitStatus> {
     let res = cmd.spawn();
     let program = cmd.get_program();
@@ -150,6 +65,17 @@ where
     cmd
 }
 
+pub fn open_editor(path: &Path) -> Result {
+    let conf = Config::get();
+    let cmd = create_concat_cmd(&conf.editor, &[&path]);
+    let stat = run_cmd(cmd)?;
+    if !stat.success() {
+        let code = stat.code().unwrap_or_default();
+        return Err(Error::EditorError(code, conf.editor.clone()));
+    }
+    Ok(())
+}
+
 pub fn create_concat_cmd<'a, 'b, I1, S1, I2, S2>(arg1: I1, arg2: I2) -> Command
 where
     I1: IntoIterator<Item = &'a S1>,
@@ -219,8 +145,14 @@ pub fn handle_fs_res<T, P: AsRef<Path>>(path: &[P], res: std::io::Result<T>) ->
     }
 }
 
-fn get_or_create_tamplate(ty: &ScriptType) -> Result<String> {
-    let tmpl_path = get_template_path(ty)?;
+pub fn get_template_path(ty: &ScriptType, force: bool) -> Result<PathBuf> {
+    if !force {
+        Config::get().get_script_conf(&ty)?; // 確認類型存在與否
+    }
+    path::get_template_path(ty)
+}
+pub fn get_or_create_tamplate(ty: &ScriptType, force: bool) -> Result<String> {
+    let tmpl_path = get_template_path(ty, force)?;
     if tmpl_path.exists() {
         return read_file(&tmpl_path);
     }
@@ -258,17 +190,6 @@ fn relative_to_home(p: &Path) -> Option<&Path> {
     p.strip_prefix(&home).ok()
 }
 
-fn find_pre_run() -> Option<PathBuf> {
-    use crate::path;
-    let p = path::get_home().join(path::HS_PRE_RUN);
-    if p.exists() {
-        log::info!("找到預執行腳本 {:?}", p);
-        Some(p)
-    } else {
-        None
-    }
-}
-
 #[derive(Debug)]
 pub enum PrepareRespond {
     HasContent,
@@ -284,8 +205,8 @@ pub fn prepare_script<T: AsRef<str>>(
     let has_content = !content.is_empty();
     let is_new = !path.exists();
     if is_new {
-        let birthplace_abs = normalize_path(".")?;
-        let birthplace = relative_to_home(&birthplace_abs);
+        let birthplace = path::normalize_path(".")?;
+        let birthplace_rel = relative_to_home(&birthplace);
 
         // NOTE: 創建資料夾和檔案
         if let Some(parent) = path.parent() {
@@ -297,13 +218,14 @@ pub fn prepare_script<T: AsRef<str>>(
         if !no_template {
             let content: Vec<_> = content.collect();
             let info = json!({
-                "birthplace_in_home": birthplace.is_some(),
+                "birthplace_in_home": birthplace_rel.is_some(),
+                "birthplace_rel": birthplace_rel,
                 "birthplace": birthplace,
-                "birthplace_abs": birthplace_abs,
                 "name": script.name.key().to_owned(),
                 "content": content,
             });
-            let template = get_or_create_tamplate(&script.ty)?;
+            // NOTE: 計算 `path` 時早已檢查過腳本類型，這裡直接不檢查了
+            let template = get_or_create_tamplate(&script.ty, true)?;
             handle_fs_res(&[path], write_prepare_script(file, &template, &info))?;
         } else {
             for line in content {
@@ -397,3 +319,15 @@ pub fn option_map_res<T, F: FnOnce(T) -> Result<T>>(opt: Option<T>, f: F) -> Res
         None => None,
     })
 }
+
+pub fn hijack_ctrlc_once() {
+    use std::sync::Once;
+    static CTRLC_HANDLE: Once = Once::new();
+    log::debug!("劫持 ctrl-c 回調");
+    CTRLC_HANDLE.call_once(|| {
+        let res = ctrlc::set_handler(|| {});
+        if res.is_err() {
+            log::warn!("設置 ctrl-c 回調失敗 {:?}", res);
+        }
+    });
+}
