@@ -24,10 +24,88 @@ fn test_history_args() {
 
 #[test]
 fn test_no_trace() {
-    let _g = setup();
     // TODO
 }
 
+#[test]
+fn test_humble_amend_rm_id() {
+    let _g = setup();
+    // 注意刪除後 humble 事件為最新的後果（可能因為寫回的緣故，越刪除時間反而更新）
+    const CONTENT: &str = r#"
+    if [ "$1" = "h" ]; then
+        $HS_EXE -H $HS_HOME history humble $HS_RUN_ID
+    elif [ "$1" = "r" ]; then
+        $HS_EXE -H $HS_HOME history rm-id $HS_RUN_ID
+    elif [ "$1" = "a" ]; then
+        $HS_EXE -H $HS_HOME history amend $HS_RUN_ID do-the-amend
+    fi"#;
+
+    let test = ScriptTest::new("test", None, Some(CONTENT));
+    let baseline = ScriptTest::new("baseline", None, None);
+
+    fn assert_last(s: &ScriptTest) {
+        s.can_find("-").unwrap();
+    }
+    let assert_history = |list: &[&str]| {
+        let recorded = run!("history show {}", test.get_name()).unwrap();
+        assert_list(&recorded, list);
+    };
+
+    test.filter("--humble").run("flag-humble").unwrap();
+    assert_last(&baseline);
+    test.run("normal").unwrap();
+    assert_last(&test);
+    run!("history rm {} 1", test.get_name()).unwrap();
+    assert_last(&baseline); // `flag-humble` 為 humbe 事件，不會影響最新事件時間
+
+    test.run("h").unwrap();
+    assert_last(&baseline);
+    assert_history(&["h", "flag-humble"]);
+
+    test.run("r").unwrap();
+    assert_last(&baseline);
+    assert_history(&["h", "flag-humble"]);
+
+    test.filter("--dummy").run("r").unwrap(); // 因為是 --dummy 所以不會觸發 rm-id
+    assert_last(&test);
+    baseline.run("").unwrap();
+    test.run("r").unwrap();
+    assert_last(&baseline);
+    assert_history(&["r", "h", "flag-humble"]); // `r` 不會因為 rm-id 就被刪掉
+
+    run!("history rm {} 1", baseline.get_name()).unwrap();
+
+    test.run("normal").unwrap();
+    assert_history(&["normal", "r", "h", "flag-humble"]);
+    run!("history rm {} 1", test.get_name()).unwrap();
+    assert_last(&test); // 刪了一個還有一個
+    run!("history rm {} 1", test.get_name()).unwrap();
+    assert_last(&baseline); // `h` 為 humble，不會影響最新事件時間
+    assert_history(&["h", "flag-humble"]);
+
+    test.run("a").unwrap();
+    assert_last(&test);
+    assert_history(&["do-the-amend", "h", "flag-humble"]);
+
+    baseline.run("").unwrap();
+    test.run("h").unwrap();
+    assert_last(&baseline);
+    assert_history(&["h", "do-the-amend", "flag-humble"]);
+
+    // 測一下 --no-trace 會不會搞爛東西
+    run!("history rm {} 1..", test.get_name()).unwrap();
+    test.filter("--no-trace").run("a").unwrap();
+    test.filter("--no-trace").run("r").unwrap();
+    test.filter("--no-trace").run("h").unwrap();
+    assert_history(&[]);
+    // 測一下 --humble 會不會搞爛東西
+    test.filter("--humble").run("a").unwrap();
+    test.filter("--humble").run("r").unwrap();
+    test.filter("--humble").run("h").unwrap();
+    assert_history(&["h", "do-the-amend"]);
+    assert_last(&baseline);
+}
+
 #[test]
 fn test_history_args_order() {
     let _g = setup();
@@ -155,11 +233,11 @@ fn test_history_args_rm_last() {
     run!("history rm - 1").unwrap(); // By
     assert_eq!(run!("run -p -").unwrap(), "Ay");
     run!("history rm - 1").unwrap(); // Ay
-    run!("run -p A").expect_err("previous args exist !?"); // fail, won't affect ordering
+    assert_eq!(run!("--no-trace -p A").expect("空的"), "A"); // no-trace, won't effect order
 
     assert_eq!(run!("run -p B").unwrap(), "Bx");
     run!("history rm - 1").unwrap(); // Bx
-    run!("run -p B").expect_err("previous args exist !?");
+    assert_eq!(run!("--no-trace -p B").expect("空的"), "B"); // no-trace, won't effect order
 
     assert_eq!(run!("run -").unwrap(), "A"); // read time
     assert_eq!(run!("run ^^").unwrap(), "C"); // create time
@@ -168,10 +246,10 @@ fn test_history_args_rm_last() {
 #[test]
 fn test_neglect_archaeology() {
     let _g = setup();
-    let t1 = ScriptTest::new("1", None);
-    let t2 = ScriptTest::new("2", None);
-    let neg1 = ScriptTest::new("neg1", None);
-    let neg2 = ScriptTest::new("neg2", None);
+    let t1 = ScriptTest::new("1", None, None);
+    let t2 = ScriptTest::new("2", None, None);
+    let neg1 = ScriptTest::new("neg1", None, None);
+    let neg2 = ScriptTest::new("neg2", None, None);
     t1.can_find_by_name().unwrap();
     t2.can_find_by_name().unwrap();
     neg1.can_find_by_name().unwrap();
@@ -250,6 +328,7 @@ fn test_event_path() {
             .expect("相對路徑就壞了？");
         assert_list(&recorded, &["c", "a"]);
 
+        // NOTE: 沒有 --no-trace 的話，下一次執行的順序會跑掉
         let output =
             run!(dir: &tmp_dir, "--no-trace run -p --dir {}", dir_b).expect("執行前一次參數壞了？");
         assert_eq!(output, "b");
